<?php


defined( 'ABSPATH' ) or exit;

/**
 * factor Template Body before content
 *
 * @type \WC_Order $order Order object
 * @type \WC_factor_Document Document object
 * @type string $type Document type
 * @type string $action Current document action
 *
 * @version 3.0.3
 * @since 3.0.0
 */

		?>
		<div id="order-<?php echo esc_attr( $order->id ); ?>" class="container">

			<header>

				<?php
					/**
					 * Fires before the document's header.
					 *
					 * @since 3.0.0
					 * @param string $type Document type
					 * @param string $action Current action running on document, one of 'print' or 'send_email'
					 * @param WC_factor_Document $document Document object
					 * @param WC_Order $order Order object
					 */
					do_action( 'wc_factor_before_header', $type, $action, $document, $order );
				?>

				<div class="document-header <?php echo $type; ?>-header">

					<div class="head company-information">

						<?php $align_title = get_option( 'wc_factor_company_title_align', 'left' ); ?>

						<div class="company-title <?php echo empty( $align_title ) ? 'left' : $align_title; ?>">

							<?php
								$logo  = $document->get_company_logo();
								$title = ! empty( $logo ) ? $document->get_company_logo() : $document->get_company_name();
							?>

							<h1 class="title"><?php echo $document->get_company_link( $title ); ?></h1>

							<?php $subtitle = $document->get_company_extra_info(); ?>

							<?php if ( $subtitle ) : ?>
								<h5 class="company-subtitle align-<?php echo $align_title; ?>"><?php echo $subtitle; ?></h5>
							<?php endif; ?>
						</div>

						<?php $align_address = get_option( 'wc_factor_company_address_align' ); ?>

						<address class="company-address <?php echo empty( $align_address ) ? 'right' : $align_address; ?>">
							<p><?php echo $document->get_company_address(); ?></p>
						</address>

						<div class="clear"></div>
					</div>
                   <div class="number-invoice">
					<?php

						/**
						 * Fires inside the document's header after company information.
						 *
						 * @since 3.0.0
						 * @param string $type Document type
						 * @param string $action Current action running on document, one of 'print' or 'email'
						 * @param WC_factor_Document $document Document object
						 * @param WC_Order $order Order object
						 */
						do_action( 'wc_factor_header', $type, $action, $document, $order );

						if ( 'pick-list' === $type ) :

							$orders_count = max( 1, count( (array) $document->order_ids ) );

							/* translators: Placeholder: %d - orders count (one or many) */
							printf( '<h3 class="order-info">' . _n( 'List of items needed to process %d order.', 'List of items needed to process %d orders.', $orders_count, 'woocommerce-factor' ) . '</h3>', $orders_count );

							/* translators: Placeholders: %1$s - date, %2$s time */
							printf( '<em>' . __( 'Printed on: %1$s at %2$s', 'woocommerce-factor' ) . '</em>', date_i18n( wc_date_format(), time() ), date_i18n( wc_time_format(), current_time( 'timestamp' ) ) );

						endif;

					?>
                    <?php if ( $document->show_shipping_method() ) : ?>

							<div class="column shipping-method">

								<h3><?php esc_html_e( 'Shipping Method', 'woocommerce-factor' ); ?></h3>

								<em>
									<?php echo $document->get_shipping_method(); ?>
								</em>
							</div>

						<?php endif; ?>
</div>
					<div class="customer-addresses">
                            <?php
                            $customer_id = get_current_user_id();

if ( ! wc_ship_to_billing_address_only() && get_option( 'woocommerce_calc_Billing' ) !== 'no' ) {
	$page_title = apply_filters( 'woocommerce_my_account_my_address_title', __( 'My Addresses', 'woocommerce' ) );
	$get_addresses    = apply_filters( 'woocommerce_my_account_get_addresses', array(
		'billing' => __( 'Billing Address', 'woocommerce' ),
		
	), $customer_id );
} else {
	$page_title = apply_filters( 'woocommerce_my_account_my_address_title', __( 'My Address', 'woocommerce' ) );
	$get_addresses    = apply_filters( 'woocommerce_my_account_get_addresses', array(
		'billing' =>  __( 'Billing Address', 'woocommerce' )
	), $customer_id );
}

$col = 1;
?>
						
						<?php if ( $document->show_shipping_address() ) : ?>

							<div class="column customer-address shipping-address">

								<h3>مشخصات مشتری</h3>
<?php if ( ! wc_ship_to_billing_address_only() && get_option( 'woocommerce_calc_Billing' ) !== 'no' ) echo ''; ?>

<?php foreach ( $get_addresses as $name => $title ) : ?>
		<address>

        <ul class="profil-acant">
        <li>
        <span>نام و نام خانوادگی : </span> <?php echo $order->billing_first_name; ?> <?php echo $order->billing_last_name; ?>
			
            </li>
            <li>
            <span>شرکت : </span>
            <?php
				
$address = apply_filters( 'woocommerce_my_account_my_address_formatted_address', array(
					'company'     => get_user_meta( $customer_id, $name . '_company', true ),
					
				), $customer_id, $name );
				$formatted_address = WC()->countries->get_formatted_address( $address );

				if ( ! $formatted_address )
					_e( '--', 'woocommerce' );
				else
					echo $formatted_address;
			?>
            </li>
             <li>
            <span>کدپستی : </span> <?php echo $order->billing_postcode; ?>
            
            </li>
            <li>
            <?php
			if($order->billing_state=='TE'){
				$state='تهران';
			}
			if($order->billing_state=='KZ'){
				$state='خوزستان';
			}
			if($order->billing_state=='AL'){
				$state='البرز';
			}
			if($order->billing_state=='Al'){
				$state='اردبیل';
			}
			if($order->billing_state=='AE'){
				$state='آذربایجان شرقی';
			}
			if($order->billing_state=='AW'){
				$state='آذربایجان غربی';
			}
			if($order->billing_state=='BU'){
				$state='بوشهر';
			}
			if($order->billing_state=='CM'){
				$state='چهارمحال و بختیاری';
			}
			if($order->billing_state=='FA'){
				$state='فارس';
			}
			if($order->billing_state=='GI'){
				$state='گیلان';
			}
			if($order->billing_state=='GO'){
				$state='گلستان';
			}
			if($order->billing_state=='HD'){
				$state='همدان';
			}
			if($order->billing_state=='HG'){
				$state='هرمزگان';
			}
			if($order->billing_state=='IL'){
				$state='ایلام';
			}
			if($order->billing_state=='IS'){
				$state='اصفهان';
			}
			if($order->billing_state=='KE'){
				$state='کرمان';
			}
			if($order->billing_state=='BK'){
				$state='کرمانشاه';
			}
			if($order->billing_state=='KS'){
				$state='خراسان شمالی';
			}
			if($order->billing_state=='KV'){
				$state='خراسان رضوی';
			}
			if($order->billing_state=='KJ'){
				$state='خراسان جنوبی';
			}
			if($order->billing_state=='KB'){
				$state='کهگیلویه و بویراحمد';
			}
			if($order->billing_state=='KD'){
				$state='کردستان';
			}
			if($order->billing_state=='LO'){
				$state='لرستان';
			}
			if($order->billing_state=='MK'){
				$state='مرکزی';
			}
			if($order->billing_state=='MN'){
				$state='مازندران';
			}
			if($order->billing_state=='QZ'){
				$state='قزوین';
			}
			if($order->billing_state=='QM'){
				$state='قم';
			}
			if($order->billing_state=='SM'){
				$state='سمنان';
			}
			if($order->billing_state=='YA'){
				$state='یزد';
			}
			if($order->billing_state=='ZA'){
				$state='زنجان';
			}
			if($order->billing_state=='SB'){
				$state='سیستان و بلوچستان';
			}
			?>
            <span>محل سکونت : </span><?php echo $state; ?> - <?php echo $order->billing_city; ?>
           
            </li>
      
            
            <li>
            <span>شماره تماس : </span>
           <?php echo $order->billing_phone; ?>
            
            </li>
                        <li>
            <span>ایمیل: </span>
            <?php echo $order->billing_email; ?>
            
            </li>
            <li>
            <span>آدرس  : </span> <?php echo $order->billing_address_1; ?>
            
            <span style="color:#3D4351"> <?php echo $order->billing_address_2; ?>
                       
            </span>
            </li>


            </ul>
		</address>
            <?php endforeach; ?>
								
							</div>

						<?php endif; ?>

						

						<div class="clear"></div>
					</div>

					<?php
						/**
						 * Fires after the customer's address is printed on the document.
						 *
						 * @since 3.0.0
						 * @param string $type Document type
						 * @param string $action Current action running on Document
						 * @param WC_factor_Document $document Document object
						 * @param WC_Order $order Order object
						 */
						do_action( 'wc_factor_after_customer_addresses', $type, $action, $document, $order );
					?>

					<?php if ( $document->show_header() ) : ?>

						<div class="document-heading <?php echo $type; ?>-heading">
							<?php echo $document->get_header(); ?>
						</div>

					<?php endif; ?>

				</div>

				<?php
					/**
					 * Fires after the document's header.
					 *
					 * @since 3.0.0
					 * @param string $type Document type
					 * @param string $action Current action running on Document
					 * @param WC_factor_Document $document Document object
					 * @param WC_Order $order Order object
					 */
					do_action( 'wc_factor_after_header', $type, $action, $document, $order );
				?>
			</header>

			<main class="document-body <?php echo $type; ?>-body">

				<?php
					/**
					 * Fires before the document's body (order table).
					 *
					 * @since 3.0.0
					 * @param string $type Document type
					 * @param string $action Current action running on Document
					 * @param WC_factor_Document $document Document object
					 * @param WC_Order $order Order object
					 */
					do_action( 'wc_factor_before_body', $type, $action, $document, $order );
				?>

				<table class="order-table <?php echo $type; ?>-order-table">
					<?php
