<?php

defined( 'ABSPATH' ) or exit;

/**
 * factor Documents Styles Template
 *
 * Use this template to override styles used in factor documents.
 * However, you can also add more styles from factor settings page
 * or hooking `wc_factor_styles` action without copying and editing
 * over this template.
 *
 * @type \WC_factor_Document $document Document object
 *
 * @version 3.1.1
 * @since 3.0.0
 */

?>
<style type="text/css">

	/* ==========*
	 * HTML TAGS *
	 * ==========*/

	html, body {
		background: #FFFFFF;
	}

	body {
		display: block;
		color: #212B3A;
		font: normal <?php echo get_option( 'wc_factor_body_font_size', '14' ); ?>px/130% IRANSans;
		margin: 8px;
		-webkit-print-color-adjust: exact;
	}

	a {
		color: <?php echo get_option( 'wc_factor_link_color', '#212B3A' ); ?>;
	}

	hr {
		margin-top: 1em;
	}

	blockquote {
		border-left: 10px solid #DDD;
		color: #212B3A;
		font-style: normal;
		margin: 1.5em;
		padding-left: 10px;
	}

	h1, h2, h3, h4, h5, h6 {
		color: <?php echo get_option( 'wc_factor_headings_color', '#212B3A' ); ?>;
		line-height: 150%;
		font-family:IRANSans;
	}

	<?php $h_size = (int) get_option( 'wc_factor_heading_font_size', '17' ); $i = 0; ?>
	<?php foreach ( array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ) as $h ) : ?>
		<?php echo $h . ' { font-size: ' . ( $h_size - ( 4 * $i ) ) . 'px; } '; $i++; ?>
	<?php endforeach; ?>

	/* Creates a separator between multiple documents */
	body > div.container:after {
		content: ' ';
		border-top: 2px dashed #DDDDDD;
		display: block;
		margin: 50px 0 0;
	}

	/* Separator doesn't apply on last document or individual documents */
	body > div.container:last-child:after {
		display: none;
	}


	/* =============== *
	 * UTILITY CLASSES *
	 * =============== */

	.left {
		float: left;
	}

	.align-left {
		text-align: left;
	}

	.right {
		float: right;
	}

	.align-right {
		text-align: right;
	}

	.center {
		float: none;
		margin: 0 auto;
		text-align: center;
		width: 100%;
	}

	.align-center {
		text-align: center;
	}

	.clear {
		clear: both;
	}

	.container {
		background: #FFF;
		margin: 1em auto;
		padding: 2em;
	}

	.container header,
	.container main,
	.container footer {
		margin: 0 auto;
		max-width: 960px;
	}

	.visible-print-block,
	.visible-print-inline,
	.visible-print-inline-block {
		display: none !important;
	}

	<?php if ( ( ! $document->show_footer() || ! $document->show_terms_and_conditions() )
				|| ( '' === $document->get_footer() || '' === $document->get_return_policy() ) ) : ?>
		footer hr {
			display: none;
		}
	<?php endif; ?>

	/* ============= *
	 * ORDER DETAILS *
	 * ============= */

	.title a {
		font-size: <?php echo ( (int) get_option( 'wc_factor_heading_font_size', '17' ) + 4 ) . 'px'; ?>;
		font-weight: 500;
		text-decoration: none;
	}

	.title,
	.subtitle {
		margin: 0;
	}

	.left .logo {
		padding-right: 1em;
	}

	.right .logo {
		padding-left: 1em;
	}

	.company-information {
		margin-bottom: 0;
	}

	.company-address {
		font-style: normal;
	}

	.customer-addresses {

	}

	.customer-addresses .column {
		padding: 0 15px;
		
		-webkit-box-sizing: border-box;
		-moz-box-sizing: border-box;
		box-sizing: border-box;
	}

	.document-heading {
		margin: 5px 0;
	}

	.order-info {
		margin-bottom: 0;
	}

	.order-date {
		color: #666666;
    margin: 7px 0;
    font-size: 15px;
    font-weight: 400;
	}

	<?php if ( 1 === (int) get_option( 'wc_factor_return_policy_fine_print' ) ) : ?>
		.terms-and-conditions {
			font-size: 90%;
			line-height: 120%;
		}
	<?php endif; ?>

	span.coupon {
		background: #F4F4F4;
		color: #212B3A;
		font-family: IRANSans;
		padding: 3px;
		border-radius:3px;
	}


	/* ===== *
	 * LISTS *
	 * ===== */

	dl {
		margin: 1em 0;
	}

	dl.variation {
		font-size: 0.85em;
		margin: 0;
	}

	dl.variation dt {
		float: right;
		margin: 0 5px 0 0;
	}

	dl.variation dd {
		display: inline;
		margin: 0;
	}

	dl.variation p {
		margin: 0;
	}
     
a{text-decoration:none;}
	/* ============ *
	 * ORDER TABLES *
	 * ============ */

	table {
		border-collapse: collapse;
		font: normal <?php echo get_option( 'wc_factor_body_font_size', '14' ); ?>px/130% IRANSans;
		margin: 10px 0 2em;
		text-align: center;
		width: 100%;
	}

	table td,
	table th {
		background: #FFFFFF;
		border: 1px solid #DDDDDD;
		font-weight: normal;
		padding: 0.8em 1.2em;
		text-transform: none;
		vertical-align: top;
	}

	table th {
		font-weight: 500;
		-webkit-print-color-adjust: exact;
	}

	table thead.order-table-head th {
		background-color: <?php echo get_option( 'wc_factor_table_head_bg_color', '#4D9DE0' ); ?>;
		border-color: <?php echo get_option( 'wc_factor_table_head_bg_color', '#ddd' ); ?>;
		color: <?php echo get_option( 'wc_factor_table_head_color', '#FFFFFF' ); ?>;
	}

	table tbody th a {
		color: #212B3A;
		font-weight: 500;
	}

	table tfoot td {
		border-color: #CCCCCC;
		border-width: 1px 0 0 0;
		border-style: solid;
		text-align: right;
	}

	table tbody tr.heading th {
		background-color: #4D9DE0;
		border-color: #ddd;
		color: #FFFFFF;
	}

	table tbody tr.heading th.order-number a {
		color: #FFF;
		font-weight: 500;
		text-decoration: none;
	}

	table tbody tr.heading th.no-items {
		background-color: #A0A0A0;
		font-weight: 400;
	}

	table tbody tr.heading th.breadcrumbs {
		background-color: #D8D8D8;
		border-color: #D8D8D8;
		color: #666666;
		font-weight: normal;
	}

	table tbody tr.even,
	table tbody tr.even td {
		background-color: #F5F5F5;
	}

	tbody tr.odd,
	tbody tr.odd td {
		background-color: #FFFFFF;
	}

	thead th.id,
	tbody td.id,
	thead th.id > span,
	tbody td.id > span {
		border: 0;
		display: none;
		overflow: hidden;
		padding: 0;
		visibility: hidden;
	}

	.quantity,
	.total-quantity {
		text-align: center;
	}

	.price,
	.weight,
	.total-weight {
		text-align: center;
	}
.product{text-align:right;}

	/* ============ *
	 * PRINT STYLES *
	 * ============ */

	@media print {

		/* Background is always white in print */
		html, body {
			background: #FFFFFF;
		}

		a {
			text-decoration: none;
		}

		/* Multiple document separators are not printed */
		body > div.container:after {
			display: none;
		}

		/* Break pages when printing multiple documents */
		.container {
			page-break-after: always;
		}
		.container:last-child {
			page-break-after: auto;
		}

		table {
			page-break-inside: auto;
		}

		table tr {
			page-break-inside: avoid;
			page-break-after: auto;
		}

		table td,
		table th {
			padding: 0.4em 1.2em;
			page-break-inside: avoid;
			page-break-after: auto;
		}

		/* Print URL after link text */
		.document-heading a:after,
		.document-footer a:after {
			content: " (" attr(href) ")";
		}

		.visible-print-block {
			display: block !important;
		}

		.visible-print-inline {
			display: inline !important;

		}

		.visible-print-inline-block {
			display: inline-block !important;
		}

		.hidden-print {
			display: none !important;
		}
	}

	<?php
		/**
		 * Fires inside the document's `<style>` element to allow for custom CSS.
		 *
		 * @since 3.0.0
		 */
		do_action( 'wc_factor_styles' );
	?>
	.shipping-address{
		     border: 1px solid #eee;
    width: 100% !important;
    padding: 0 !important;
    margin: 33px 0 0;
    position: relative;
	}
	 .shipping-address h3{
	        background: #fff;
    border: 1px solid #cecece;
    display: inline-block;
    padding: 5px;
    font-size: 16px;
    font-weight: 400;
    border-radius: 5px;
    position: absolute;
    right: 12px;
    top: -38px;
	}
	.shipping-address address{
		    padding: 0px 6px 0px;
	}
	.number-invoice{    position: relative;}
	.shipping-method{   position: absolute;
    top: 0;
    left: 0;
    background: #f8f8f8;
    padding: 11px;
    border-radius: 3px;
    text-align: center;}
	.shipping-method h3{    font-size: 16px;
    margin: 0;
    font-weight: 400;}
	.shipping-method em{
		color:#EB4549;
		font-style:normal;}
		.cou-note{}
		.cou-note .right-box{        width: 45%;
    float: right;}
		.cou-note .left-box{    width: 50%;
    float: left;
    border: 1px solid #dadada;
    border-radius: 5px;
    padding: 10px;
	position: relative;
	
	}
	.cou-note .left-box h3{
	        background: #fff;
    border: 1px solid #cecece;
    display: inline-block;
    padding: 5px;
    font-size: 16px;
    font-weight: 400;
    border-radius: 5px;
    position: absolute;
    right: 12px;
    top: -38px;
	}
	.customer-note{    padding: 15px 5px 0;}
	.value{text-align:center;}
	.profil-acant{
    padding: 0;
    list-style: none;
    display: inline-block;
}
.profil-acant li {
    font-size: 15px;
    color: #3D4351;
    float: right;
    padding: 8px;
    font-style: normal;
    font-weight: normal;
}
.profil-acant li span{
    color: #84B32B;
}
.lostpost-but{
    position: absolute;
    bottom: 17px;
    left: 27px;
    background: #33AAE1;
    border-bottom: 3px solid #2090C3;
    color: #fff;
    padding: 8px;
    font-family: BYekan;
    font-size: 14px;
    border-radius: 3px;
}
.document-colophon{text-align:center;}
</style>
